GBClientTermination

package
v0.0.0-...-3040e0b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2015 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckForProgramEnd

func CheckForProgramEnd(mustExit chan bool)

CheckForProgramEnd checks for a kill signal from the Cocoa app (if the user quits, for example).

func GracefullyExit

func GracefullyExit(tlsConn *tls.Conn, key []byte)

GracefullyExit is the default exit method for the binary.

Types

This section is empty.

Jump to