GBServerWatch

package
v0.0.0-...-3040e0b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2015 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckForFileToSendFromServer

func CheckForFileToSendFromServer(UserCollection *mgo.Collection, username string, RSA_Public_Key string) (GBServerDatabase.FileQueue, error)

CheckForFilesToSendFromServer checks for the files to send from a client, and returns the first one of the commands.

Types

type OutputData

type OutputData struct {
	Path              string `bson: "path"`
	Is_dir            bool   `bson: "is_dir"`
	Modification_time int64  `bson: "modification_time"`
	Size              int64  `bson: "size"`
}

OutputData is used as the communication of data in channels

Jump to