Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckForProgramEnd ¶
func CheckForProgramEnd(mustExit chan bool)
CheckForProgramEnd checks for a kill signal from the Cocoa app (if the user quits, for example).
func GracefullyExit ¶
GracefullyExit is the default exit method for the binary.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.