Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckForFileToSendFromServer ¶
func CheckForFileToSendFromServer(UserCollection *mgo.Collection, username string, RSA_Public_Key string) (GBServerDatabase.FileQueue, error)
CheckForFilesToSendFromServer checks for the files to send from a client, and returns the first one of the commands.
Types ¶
Click to show internal directories.
Click to hide internal directories.